# daschat-handsoff-base

Base package for the development of integration modules with chat applications for the handsoff of conversations.


<p align="center">
<a href="https://www.python.org/">
    <img src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg"
        alt = "Made with Python">
</a>

<a href="https://pypi.python.org/pypi/daschat_base">
    <img src="https://img.shields.io/pypi/v/daschat_base.svg"
        alt = "Release Status">
</a>

<a href="https://github.com/daschat-io/daschat_base/actions">
    <img src="https://github.com/daschat-io/daschat_base/actions/workflows/main.yml/badge.svg?branch=release" alt="CI Status">
</a>

<!-- <a href="https://daschat-handsoff-base.readthedocs.io/en/latest/?badge=latest">
    <img src="https://readthedocs.org/projects/daschat-base/badge/?version=latest" alt="Documentation Status">
</a> -->

</p>

## Features

* Free software: MIT
* Documentation: <https://daschat-io.github.io/daschat_base/>


## Enabling Python versions

Install Python versions using `pyenv` and enable all versions to be used with `tox`:

``` console
$ pyenv install 3.8.10 3.9.5
$ pyenv shell 3.8.10 3.9.5
$ pyenv local 3.8.10
```

## Acknowledgements

 - [Cookiecutter](https://github.com/audreyr/cookiecutter)
 - [zillionare/cookiecutter-pypackage](https://github.com/zillionare/cookiecutter-pypackage)
 - [Naereen/badges](https://github.com/Naereen/badges)
